@@ -63,6 +63,7 @@ extern void gsr_add_recent (gchar *filename);
 #define KEY_OPEN_DIR        GCONF_DIR "system-state/open-file-directory"
 #define KEY_SAVE_DIR        GCONF_DIR "system-state/save-file-directory"
 #define KEY_LAST_PROFILE_ID GCONF_DIR "last-profile-id"
+#define KEY_LAST_INPUT      GCONF_DIR "last-input"
 #define EBUSY_TRY_AGAIN     3000    /* Empirical data */
 
 typedef struct _GSRWindowPipeline {
@@ -173,6 +174,7 @@ show_error_dialog (GtkWindow *win, const gchar *dbg, const gchar * format, ...)
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
 					 GTK_BUTTONS_CLOSE,
+					 "%s",
 					 s);
 
 	if (dbg != NULL) {
@@ -283,7 +285,6 @@ seconds_to_full_string (guint seconds)
 	char *time = NULL;
 	const char *minutefmt;
 	const char *hourfmt;
-	const char *dayfmt;
 	const char *secondfmt;
 
 	days    = seconds / (60 * 60 * 24);
@@ -1214,7 +1215,7 @@ help_contents_cb (GtkAction *action,
 
 	if (error != NULL)
 	{
-		g_warning (error->message);
+		g_warning ("%s", error->message);
 
 		g_error_free (error);
 	}
@@ -1321,7 +1322,7 @@ record_cb (GtkAction *action,
 		window->priv->len_secs = 0;
 		window->priv->saved = FALSE;
 
-		g_print (priv->record_filename);
+		g_print ("%s", priv->record_filename);
 		g_object_set (G_OBJECT (priv->record->sink),
 			      "location", priv->record_filename,
 			      NULL);
@@ -1878,14 +1879,15 @@ record_input_changed_cb (GtkComboBox *input, GSRWindow *window)
 
 	gst_mixer_set_record (window->priv->mixer, selected, TRUE);
 	GST_DEBUG ("input changed to: %s\n", selected->label);
+	gconf_client_set_string (gconf_client, KEY_LAST_INPUT, selected->label, NULL);
 }
 
 static void
 fill_record_input (GSRWindow *window, gchar *selected)
 {
-	GstElement *e;
 	const GList *l;
 	int i = 0;
+	int last_possible_i = 0;
 	GtkTreeModel *model;
 
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (window->priv->input));
@@ -1912,25 +1914,30 @@ fill_record_input (GSRWindow *window, gchar *selected)
 			gtk_combo_box_append_text (GTK_COMBO_BOX (window->priv->input), t->label);
 			++i;
 		}
-		if ((t->flags & GST_MIXER_TRACK_RECORD) && (selected == NULL)) {
-			gtk_combo_box_set_active (GTK_COMBO_BOX (window->priv->input), i - 1);
+		if (t->flags & GST_MIXER_TRACK_RECORD) {
+			if (selected == NULL) {
+				gtk_combo_box_set_active (GTK_COMBO_BOX (window->priv->input), i - 1);
+			} else {
+				last_possible_i = i;
+			}
 		}
 		if ((selected != NULL) && g_str_equal (selected, t->label)) {
 			gtk_combo_box_set_active (GTK_COMBO_BOX (window->priv->input), i - 1);
 		}
 	}
 
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (window->priv->input)) == -1) {
+		gtk_combo_box_set_active (GTK_COMBO_BOX (window->priv->input), last_possible_i - 1);
+	}
+
 	gtk_widget_show (window->priv->input);
 	gtk_widget_show (window->priv->input_label);
 }
 
-gboolean
+static gboolean
 level_message_handler_cb (GstBus * bus, GstMessage * message, GSRWindow *window)
 {
-  GSRWindowPrivate *priv;
-  GstState cur_state, pending;
-
-  priv = window->priv;
+  GSRWindowPrivate *priv = window->priv;
 
   if (message->type == GST_MESSAGE_ELEMENT) {
     const GstStructure *s = gst_message_get_structure (message);
@@ -1957,7 +1964,7 @@ level_message_handler_cb (GstBus * bus, GstMessage * message, GSRWindow *window)
 	myind = exp (peak_dB / 20);
 	if (myind > 1.0)
 		myind = 1.0;
-	gtk_progress_set_percentage (GTK_PROGRESS (window->priv->level), myind);
+	gtk_progress_set_percentage (GTK_PROGRESS (priv->level), myind);
       }
     }
   }
@@ -2232,11 +2239,10 @@ gsr_window_init (GSRWindow *window)
 	GtkWidget *align;
 	GtkWidget *frame;
 	gchar *id;
+	gchar *last_input;
 	gchar *path;
 	GtkAction *action;
 	GtkShadowType shadow_type;
-	GstElement *source;
-
 	window->priv = GSR_WINDOW_GET_PRIVATE (window);
 	priv = window->priv;
 
@@ -2358,10 +2364,6 @@ gsr_window_init (GSRWindow *window)
 	g_signal_connect (priv->input, "changed",
 			  G_CALLBACK (record_input_changed_cb), window);
 
-	atk_object_add_relationship (gtk_widget_get_accessible (GTK_WIDGET (priv->input)),
-				ATK_RELATION_LABELLED_BY,
-				gtk_widget_get_accessible (GTK_WIDGET (label)));
-
 	/* choose profile */
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (content_vbox), hbox, FALSE, FALSE, 0);
@@ -2490,7 +2492,11 @@ gsr_window_init (GSRWindow *window)
 			    _("Ready"));
 
 	gtk_widget_show_all (main_vbox);
-	fill_record_input (window, NULL);
+	last_input = gconf_client_get_string (gconf_client, KEY_LAST_INPUT, NULL);
+	fill_record_input (window, last_input);
+	if (last_input) {
+		g_free (last_input);
+	}
 
 	/* Make the pipelines */
 	priv->play = NULL;
