@@ -67,7 +67,7 @@ gst_properties_gconf_get_string (const gchar * key)
   g_free (full_key);
 
   if (error) {
-    g_warning ("%s() error: %s", G_GNUC_PRETTY_FUNCTION, error->message);
+    g_warning ("%s() error: %s", G_STRFUNC, error->message);
     g_error_free (error);
     return NULL;
   }
@@ -87,7 +87,7 @@ gst_properties_gconf_set_string (const gchar * key, const gchar * value)
   g_free (full_key);
 
   if (error) {
-    g_warning ("%s() error: %s", G_GNUC_PRETTY_FUNCTION, error->message);
+    g_warning ("%s() error: %s", G_STRFUNC, error->message);
     g_error_free (error);
   }
 }
@@ -587,11 +587,10 @@ init_pipeline_editor (GladeXML * dialog, GSTPPipelineEditor * editor)
   }
 }
 
-void
+static void
 create_dialog (void)
 {
   int i = 0;
-  GdkPixbuf *icon = NULL;
 
   for (i = 0; i < pipeline_editors_count; i++) {
     init_pipeline_editor (interface_xml, pipeline_editors + i);
@@ -607,15 +606,7 @@ create_dialog (void)
 
   g_signal_connect (G_OBJECT (main_window),
       "response", (GCallback) dialog_response, interface_xml);
-  icon =
-      gdk_pixbuf_new_from_file (GSTPROPS_ICONDIR "/gstreamer-properties.png",
-      NULL);
-  if (icon) {
-    gtk_window_set_icon (GTK_WINDOW (main_window), icon);
-  } else {
-    g_warning ("Error loading main window icon %s",
-        GSTPROPS_ICONDIR "/gstreamer-properties.png\n");
-  }
+  gtk_window_set_icon_name (GTK_WINDOW (main_window), "gstreamer-properties");
   gtk_widget_show (GTK_WIDGET (main_window));
 }
 
@@ -623,7 +614,7 @@ int
 main (int argc, char **argv)
 {
   GOptionContext *ctx;
-  GOptionGroup *group;
+  GnomeProgram *program;
 
   g_thread_init (NULL);
 
@@ -634,7 +625,7 @@ main (int argc, char **argv)
   ctx = g_option_context_new ("gstreamer-properties");
   g_option_context_add_group (ctx, gst_init_get_option_group ());
 
-  gnome_program_init ("gstreamer-properties", VERSION,
+  program = gnome_program_init ("gstreamer-properties", VERSION,
       LIBGNOMEUI_MODULE, argc, argv,
       GNOME_PARAM_GOPTION_CONTEXT, ctx,
       GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
@@ -662,6 +653,7 @@ main (int argc, char **argv)
 
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
+    g_object_unref (program);
 
     exit (1);
   }
@@ -672,6 +664,7 @@ main (int argc, char **argv)
     gtk_main ();
 
   g_object_unref (gconf_client);
+  g_object_unref (program);
 
   return 0;
 }
